==> nextcloud-php74-20.0.7.txz: usr/local/www/nextcloud/apps-pkg/updatenotification/l10n/sl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Na voljo je nova različica {version}. Oglejte si več podrobnosti o nadgradnji.",
    "Channel updated" : "Kanal je posodobljen",
    "Update notifications" : "Obvestila o posodobitvah",
    "The update server could not be reached since %d days to check for new updates." : "Vzpostavitev povezave s strežnikom za posodobitve ni mogoče že %d dni.",
    "Please check the Nextcloud and server log files for errors." : "Preverite strežniške in sistemske dnevnike za napake.",
    "Update to %1$s is available." : "Na voljo je posodobitev na %1$s.",
    "Update for %1$s to version %2$s is available." : "Na voljo je posodobitev %1$s na različico %2$s.",
    "Update for {app} to version %s is available." : "Na voljo je posodobitev programa {app} na različico %s.",
    "Update notification" : "Obvestilo o posodobitvi",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Pokaže obvestila o posodobitvah okolja Nextcloud in omogoča prijavo SSO za posodabljalnik.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Različica, ki je trenutno v uporabi, ni več vzdrževana. Priporočljivo je čim prej posodobiti okolje!",
    "Apps missing updates" : "Manjkajoče programske posodobitve",
    "View in store" : "Pokaži v trgovini",
    "Apps with available updates" : "Programi z objavljenimi posodobitvami",
    "Open updater" : "Odpri posodabljalnik",
    "Download now" : "Prejmi takoj",
    "What's new?" : "Kaj je novega?",
    "The update check is not yet finished. Please refresh the page." : "Preverjanje za posodobitve še ni končano. Osvežite stran za ponovno vzpostavitev seje.",
    "Your version is up to date." : "Nameščena je najnovejša različica.",
    "A non-default update server is in use to be checked for updates:" : "Za posodobitev bo uporabljen neprivzet strežnik:",
    "Update channel:" : "Posodobi kanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Nadgradnja na višjo različico je vedno mogoča, ne pa tudi povrnitev na predhodno, bolj stabilno.",
    "Notify members of the following groups about available updates:" : "Člani navedenih skupin, ki so obveščeni o posodobitvah:",
    "Only notification for app updates are available." : "Na voljo so le obvestila za posodobitve programov.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Izbran kanal za posodobitve onemogoča obvestila s strežnika.",
    "The selected update channel does not support updates of the server." : "Izbran kanal za posodobitve ne omogoča posodobitev stražnika.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Na voljo je nova različica: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Nazadnje preverjeno {lastCheckedDate}",
    "Checking apps for compatible updates" : "Poteka preverjanje za skladne posodobitve ...",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Prepričajte se, da v datoteki config.php možnost <samp>appstoreenabled</samp> ni nastavljena na vrednost napak – false.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "S trgovino se ni mogoče povezati, ali pa usklajevanje ni vrnilo nobenih posodobitev. Te je mogoče poiskati tudi ročno, priporočljivo pa je preveriti, ali ima strežnik dostop do interneta in je povezava s trgovino sploh mogoča.",
    "<strong>All</strong> apps have an update for this version available" : "Za <strong>vse nameščene programe</strong> je na voljo podprta posodobitev.",
    "View changelog" : "Ogled Dnevnika sprememb",
    "Enterprise" : "Poslovno",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Za poslovno uporabo. Na voljo so najnovejši popravki programov in manjše posodobitve, ne pa tudi takojšnja nadgradnja sistema na naslednjo večjo različico. Ta posodobitev je na voljo šele po daljšem in podrobnejšem preizkušanju sistema. Ta kanal je na voljo le naročnikom, ki uporabljajo paket Nextcloud Enterprise.",
    "Stable" : "Stabilno",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Najnovejša stabilna različica je primerna za običajno rabo in bo vedno posodobljena na zadnjo najvišjo različico.",
    "Beta" : "Preizkusno",
    "A pre-release version only for testing new features, not for production environments." : "Preizkusna različica je namenjena preizkušanju novih zmožnosti in ni primerna za produkcijska okolja.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["Za <strong>%n</strong> program je na voljo posodobitev za to različico.","Za <strong>%n</strong> programa so na voljo posodobitve za to različico.","Za <strong>%n</strong> programe so na voljo posodobitve za to različico.","Za <strong>%n</strong> programov so na voljo posodobitve za to različico."],
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Po vsaki novi objavi je lahko tudi daljši časovni zamik, preden se posodobitev pojavi v sistemu. Nove različice objavljamo v časovnih razmikih in včasih kakšno tudi preskočimo, če prvi uporabniki zaznajo težave, ali napake."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-php74-21.0.2.txz: usr/local/www/nextcloud/apps-pkg/updatenotification/l10n/sl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Na voljo je nova različica {version}. Oglejte si več podrobnosti o nadgradnji.",
    "Channel updated" : "Kanal je posodobljen",
    "Web updater is disabled" : "Spletni posodabljalnik je onemogočen",
    "Update notifications" : "Obvestila o posodobitvah",
    "The update server could not be reached since %d days to check for new updates." : "Vzpostavitev povezave s strežnikom za posodobitve ni mogoče že %d dni.",
    "Please check the Nextcloud and server log files for errors." : "Preverite strežniške in sistemske dnevnike za napake.",
    "Update to %1$s is available." : "Na voljo je posodobitev na %1$s.",
    "Update for %1$s to version %2$s is available." : "Na voljo je posodobitev %1$s na različico %2$s.",
    "Update for {app} to version %s is available." : "Na voljo je posodobitev programa {app} na različico %s.",
    "Update notification" : "Obvestilo o posodobitvi",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Pokaže obvestila o posodobitvah okolja Nextcloud in omogoča prijavo SSO za posodabljalnik.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Različica, ki je trenutno v uporabi, ni več vzdrževana. Priporočljivo je čim prej posodobiti okolje!",
    "Apps missing compatible version" : "Programi brez podprte različice",
    "View in store" : "Pokaži v trgovini",
    "Apps with compatible version" : "Programi s podprto različico",
    "Open updater" : "Odpri posodabljalnik",
    "Download now" : "Prejmi takoj",
    "Please use the command line updater to update." : "Za posodabljanje uporabite možnosti prek ukazne vrstice.",
    "What's new?" : "Kaj je novega?",
    "The update check is not yet finished. Please refresh the page." : "Preverjanje za posodobitve še ni končano. Osvežite stran za ponovno vzpostavitev seje.",
    "Your version is up to date." : "Nameščena je najnovejša različica.",
    "A non-default update server is in use to be checked for updates:" : "Za posodobitev bo uporabljen neprivzet strežnik:",
    "Update channel:" : "Posodobi kanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Nadgradnja na višjo različico je vedno mogoča, ne pa tudi povrnitev na predhodno, bolj stabilno.",
    "Notify members of the following groups about available updates:" : "Člani navedenih skupin, ki so obveščeni o posodobitvah:",
    "Only notifications for app updates are available." : "Na voljo so le obvestila za posodobitve programov.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Izbran kanal za posodobitve onemogoča obvestila s strežnika.",
    "The selected update channel does not support updates of the server." : "Izbran kanal za posodobitve ne omogoča posodobitev stražnika.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Na voljo je nova različica: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Po vsaki novi objavi je lahko tudi daljši časovni zamik, preden se posodobitev pojavi v sistemu in se pokaže šele po prvi posodobitvi. Nove različice objavljamo v časovnih razmikih in včasih kakšno tudi preskočimo, če prvi uporabniki zaznajo težave ali napake. Več podrobnosti o kanalih objav je zbranih na povezavi {link}.",
    "Checked on {lastCheckedDate}" : "Nazadnje preverjeno {lastCheckedDate}",
    "Checking apps for compatible versions" : "Preverjanje skladnih posodobitev različic programov",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Prepričajte se, da v datoteki config.php možnost <samp>appstoreenabled</samp> ni nastavljena na vrednost napak – false.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "S trgovino se ni mogoče povezati, ali pa usklajevanje ni vrnilo nobenih posodobitev. Te je mogoče poiskati tudi ročno, priporočljivo pa je preveriti, ali ima strežnik dostop do interneta in je povezava s trgovino sploh mogoča.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>Vsi</strong> nameščeni programi imajo pripravljene posodobitve, skladne s to različico okolja Nextcloud.",
    "View changelog" : "Ogled Dnevnika sprememb",
    "Enterprise" : "Poslovno",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Za poslovno uporabo. Na voljo so najnovejši popravki programov in manjše posodobitve, ne pa tudi takojšnja nadgradnja sistema na naslednjo večjo različico. Ta posodobitev je na voljo šele po daljšem in podrobnejšem preizkušanju sistema. Ta kanal je na voljo le naročnikom, ki uporabljajo paket Nextcloud Enterprise.",
    "Stable" : "Stabilno",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Najnovejša stabilna različica je primerna za običajno rabo in bo vedno posodobljena na zadnjo najvišjo različico.",
    "Beta" : "Preizkusno",
    "A pre-release version only for testing new features, not for production environments." : "Preizkusna različica je namenjena preizkušanju novih zmožnosti in ni primerna za produkcijska okolja.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["S to različico okolja Nextcloud ima potrjene skladne posodobitve <strong>%n</strong> nameščen program.","S to različico okolja Nextcloud imata potrjene skladne posodobitve <strong>%n</strong> nameščena programa.","S to različico okolja Nextcloud imajo potrjene skladne posodobitve <strong>%n</strong> nameščeni programi.","S to različico okolja Nextcloud ima potrjene skladne posodobitve <strong>%n</strong> nameščenih programov."],
    "Apps missing updates" : "Manjkajoče programske posodobitve",
    "Apps with available updates" : "Programi z objavljenimi posodobitvami",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Po vsaki novi objavi je lahko tudi daljši časovni zamik, preden se posodobitev pojavi v sistemu. Nove različice objavljamo v časovnih razmikih in včasih kakšno tudi preskočimo, če prvi uporabniki zaznajo težave ali napake.",
    "Only notification for app updates are available." : "Na voljo so le obvestila za posodobitve programov.",
    "Checking apps for compatible updates" : "Poteka preverjanje za skladne posodobitve ...",
    "<strong>All</strong> apps have an update for this version available" : "Za <strong>vse nameščene programe</strong> je na voljo podprta posodobitev.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["Za <strong>%n</strong> program je na voljo posodobitev za to različico.","Za <strong>%n</strong> programa so na voljo posodobitve za to različico.","Za <strong>%n</strong> programe so na voljo posodobitve za to različico.","Za <strong>%n</strong> programov so na voljo posodobitve za to različico."]
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
